"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/Input/utils.tsx
var utils_exports = {};
__export(utils_exports, {
  getClasses: () => getClasses,
  getFormControlClass: () => getFormControlClass,
  getTag: () => getTag,
  getValidationTextControlClass: () => getValidationTextControlClass,
  useFocus: () => useFocus
});
module.exports = __toCommonJS(utils_exports);
var import_classnames = __toESM(require("classnames"), 1);
var import_react = require("react");

// src/utils.tsx
function mapToCssModules(className, cssModules) {
  let finalClassNames = className == null ? "" : className;
  if (!cssModules) {
    return finalClassNames;
  }
  return finalClassNames.split(" ").map((klass) => cssModules[klass] ?? klass).join(" ");
}

// src/Input/utils.tsx
function getFormControlClassInternal({ plaintext, staticInput, type = "text", addon, normalized }) {
  const formControlClass = "form-control";
  if (plaintext || staticInput || normalized) {
    return `${formControlClass}-plaintext`;
  }
  if (type === "file") {
    return `${formControlClass}-file`;
  }
  if (["radio", "checkbox"].indexOf(type) > -1) {
    if (addon) {
      return null;
    }
  }
  return formControlClass;
}
function getFormControlClass(props, cssModule) {
  return mapToCssModules(getFormControlClassInternal(props), cssModule);
}
function getValidationTextControlClass({ valid }, cssModule) {
  return mapToCssModules(
    (0, import_classnames.default)({
      "form-text": true,
      "form-feedback just-validate-error-label": valid == false
    }),
    cssModule
  );
}
function getTag({ tag, plaintext, staticInput, type = "text" }) {
  if (tag) {
    return tag;
  }
  if (["radio", "checkbox"].indexOf(type) > -1) {
    return "input";
  }
  if (plaintext || staticInput) {
    return "p";
  }
  return "input";
}
function getClasses(className, type, {
  isFocused,
  valid,
  bsSize,
  placeholder,
  value,
  label,
  validationText,
  normalized,
  inputPassword,
  formControlClass,
  validationTextControlClass,
  originalWrapperClass
}, cssModule) {
  const hasPlainCondition = placeholder || label || validationText;
  const baseCondition = hasPlainCondition && !normalized && !inputPassword;
  const passwordOnlyCondition = inputPassword && !hasPlainCondition && !normalized;
  const normalizedOnlyCondition = normalized && !hasPlainCondition && !inputPassword;
  const classes = mapToCssModules(
    (0, import_classnames.default)(
      className,
      {
        "is-invalid": valid == false,
        "just-validate-success-field": valid,
        [`form-control-${bsSize}`]: bsSize
      },
      formControlClass
    ),
    cssModule
  );
  const wrapperClass = mapToCssModules((0, import_classnames.default)(className, originalWrapperClass, "form-group"), cssModule);
  const validationTextClass = mapToCssModules(
    (0, import_classnames.default)(
      {
        "valid-feedback": valid,
        "invalid-feedback form-feedback just-validate-error-label": valid == false
      },
      validationTextControlClass
    ),
    cssModule
  );
  const inputClasses = mapToCssModules(
    (0, import_classnames.default)(
      classes,
      !baseCondition && {
        // we can model here only if stylings
        "form-control-plaintext": normalizedOnlyCondition,
        "form-control": passwordOnlyCondition,
        "input-password": passwordOnlyCondition,
        "focus--mouse": passwordOnlyCondition || normalizedOnlyCondition
      }
    ),
    cssModule
  );
  const activeClass = mapToCssModules(
    (0, import_classnames.default)({
      active: isFocused || placeholder || value || ["date", "time"].includes(type)
    }),
    cssModule
  );
  const extraLabelClass = mapToCssModules(
    (0, import_classnames.default)({
      "input-number-label": ["number", "currency", "adaptive", "percentage"].includes(type)
    })
  );
  return {
    wrapperClass,
    inputClasses,
    activeClass,
    extraLabelClass,
    validationTextClass
  };
}
function useFocus({
  onFocus,
  onBlur
}) {
  const [isFocused, setFocus] = (0, import_react.useState)(false);
  const toggleFocusLabel = (0, import_react.useCallback)(
    (e) => {
      setFocus(true);
      onFocus?.(e);
    },
    [onFocus]
  );
  const toggleBlurLabel = (0, import_react.useCallback)(
    (e) => {
      if (e.target.value === "") {
        setFocus(!isFocused);
      }
      onBlur?.(e);
    },
    [isFocused, onBlur]
  );
  return { toggleFocusLabel, toggleBlurLabel, isFocused };
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  getClasses,
  getFormControlClass,
  getTag,
  getValidationTextControlClass,
  useFocus
});
//# sourceMappingURL=utils.cjs.map