"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/NavScroll/useNavScroll.ts
var useNavScroll_exports = {};
__export(useNavScroll_exports, {
  useNavScroll: () => useNavScroll
});
module.exports = __toCommonJS(useNavScroll_exports);
var import_react2 = require("react");

// src/NavScroll/debounce.ts
var debounce = (callback, wait) => {
  let timeoutId;
  return (...args) => {
    clearTimeout(timeoutId);
    timeoutId = setTimeout(() => {
      callback.apply(null, args);
    }, wait);
  };
};

// src/NavScroll/useSizeDetector.ts
var import_react = require("react");
var DEFAULT_DELAY = 150;
var useSizeDetector = ({
  root,
  isHorizontal,
  activeId,
  onChange,
  setForceRecompute,
  updateActiveId,
  hasWindow: hasWindow2
}) => {
  const [targetSize, setTargetSize] = (0, import_react.useState)(1);
  const useViewport = root == null || hasWindow2 && (isHorizontal ? window.innerWidth < root.clientWidth : window.innerHeight < root.clientHeight);
  const scrollEnd = (0, import_react.useCallback)(
    debounce(() => {
      setForceRecompute(true);
    }, DEFAULT_DELAY),
    [setForceRecompute]
  );
  (0, import_react.useEffect)(() => {
    if (!hasWindow2) {
      return;
    }
    let observer = null;
    const resizeWindowHandler = () => {
      setTimeout(() => {
        setTargetSize(isHorizontal ? window.innerWidth : window.innerHeight);
      }, DEFAULT_DELAY);
    };
    const resizeElementHandler = (entries) => {
      const [entry] = entries;
      if (!useViewport) {
        setTargetSize(isHorizontal ? entry.boundingClientRect.width : entry.boundingClientRect.height);
      }
      if (entry.intersectionRatio === 0) {
        if (activeId != null) {
          updateActiveId(null);
          if (onChange) {
            onChange({
              added: null,
              removed: activeId
            });
          }
        }
      }
    };
    addEventListener("scroll", scrollEnd);
    if (useViewport) {
      setTargetSize(isHorizontal ? window.innerWidth : window.innerHeight);
      addEventListener("resize", resizeWindowHandler);
    }
    if (root) {
      observer = new IntersectionObserver(resizeElementHandler);
      observer.observe(root);
    }
    return () => {
      if (observer) {
        observer.disconnect();
      }
      removeEventListener("resize", resizeWindowHandler);
      removeEventListener("scroll", scrollEnd);
    };
  }, [root, isHorizontal, activeId, onChange, useViewport, scrollEnd, hasWindow2, updateActiveId]);
  return { targetSize, useViewport };
};

// src/NavScroll/useNavScroll.ts
var hasWindow = typeof window !== "undefined";
var REGISTER_DELAY = 50;
function resolveHierarchyIds(id, lookup) {
  const newActiveIds = [id];
  let lastId = newActiveIds[0];
  while (lastId != null && lookup[lastId] != null) {
    newActiveIds.push(lookup[lastId]);
    lastId = lookup[lastId];
  }
  return newActiveIds.reverse();
}
function useNavScroll(args = {}) {
  const { onChange, root, offset = 50, isHorizontal = false } = args;
  const els = (0, import_react2.useRef)([]);
  const [counter, setCounter] = (0, import_react2.useState)(0);
  const [forceRecompute, setForceRecompute] = (0, import_react2.useState)(false);
  const [activeId, updateActiveId] = (0, import_react2.useState)(null);
  const { targetSize, useViewport } = useSizeDetector({
    root,
    isHorizontal,
    onChange,
    activeId,
    setForceRecompute,
    updateActiveId,
    hasWindow
  });
  const observerMargin = Math.floor(targetSize * offset / 100) || 1;
  const observerOptions = (0, import_react2.useMemo)(() => {
    const topMargin = observerMargin % 2 === 1 ? observerMargin - 1 : observerMargin;
    const bottomMargin = targetSize - observerMargin;
    return {
      root: useViewport ? null : root,
      rootMargin: isHorizontal ? `0px ${-topMargin}px 0px ${-bottomMargin}px` : `${-topMargin}px 0px ${-bottomMargin}px 0px`
    };
  }, [root, targetSize, observerMargin, isHorizontal, useViewport]);
  const elsLookup = (0, import_react2.useMemo)(() => {
    const lookup = {};
    for (const { id, parent } of els.current) {
      lookup[id] = parent;
    }
    return lookup;
  }, []);
  const activeIds = (0, import_react2.useMemo)(() => activeId ? resolveHierarchyIds(activeId, elsLookup) : [], [activeId, elsLookup]);
  const activeLookups = (0, import_react2.useMemo)(() => new Set(activeIds), [activeIds]);
  (0, import_react2.useEffect)(() => {
    if (!hasWindow) {
      return;
    }
    const handleIntersection = (entries) => {
      let intersectionId = null;
      let topMin = Infinity;
      entries.forEach((entry) => {
        if (entry.isIntersecting) {
          if (topMin > entry.boundingClientRect.top) {
            topMin = entry.boundingClientRect.top;
            intersectionId = entry.target.id;
          }
        }
      });
      if (intersectionId != null) {
        updateActiveId(intersectionId);
        if (onChange) {
          const diffIds = {
            added: intersectionId,
            removed: activeId
          };
          onChange(diffIds);
        }
      }
    };
    const observer = new IntersectionObserver(handleIntersection, observerOptions);
    els.current.forEach(({ ref }) => {
      if (ref && ref.current) {
        observer.observe(ref.current);
      }
    });
    if (forceRecompute) {
      handleIntersection(observer.takeRecords(), observer);
      setForceRecompute(false);
    }
    return () => {
      observer.disconnect();
    };
  }, [
    activeIds,
    updateActiveId,
    els,
    elsLookup,
    onChange,
    activeLookups,
    activeId,
    observerOptions,
    isHorizontal,
    root,
    forceRecompute
  ]);
  const refresh = (0, import_react2.useCallback)(() => {
    debounce(() => {
      setCounter(counter + 1);
    }, REGISTER_DELAY);
  }, [counter]);
  const register = (0, import_react2.useCallback)(
    (id, options = {}) => {
      if (!hasWindow) {
        return { id, ref: null };
      }
      const alreadyRegistered = id in elsLookup;
      const entry = alreadyRegistered ? els.current.find(({ id: existingId }) => existingId === id) : options;
      const ref = entry && entry.ref || (0, import_react2.createRef)();
      if (!alreadyRegistered) {
        els.current = [...els.current, { id, ref, parent: options.parent }];
        refresh();
      }
      return { id, ref };
    },
    [elsLookup, refresh]
  );
  const unregister = (0, import_react2.useCallback)((idToUnregister) => {
    els.current = els.current.filter(({ id }) => id !== idToUnregister);
  }, []);
  const isActive = (0, import_react2.useCallback)((id) => activeLookups.has(id), [activeLookups]);
  const getActiveRef = (0, import_react2.useCallback)(() => {
    const entry = els.current.find(({ id }) => id === activeId);
    return entry ? entry.ref : null;
  }, [activeId]);
  return {
    register,
    unregister,
    activeIds,
    isActive,
    getActiveRef
  };
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  useNavScroll
});
//# sourceMappingURL=useNavScroll.cjs.map