"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/NavScroll/useSizeDetector.ts
var useSizeDetector_exports = {};
__export(useSizeDetector_exports, {
  useSizeDetector: () => useSizeDetector
});
module.exports = __toCommonJS(useSizeDetector_exports);
var import_react = require("react");

// src/NavScroll/debounce.ts
var debounce = (callback, wait) => {
  let timeoutId;
  return (...args) => {
    clearTimeout(timeoutId);
    timeoutId = setTimeout(() => {
      callback.apply(null, args);
    }, wait);
  };
};

// src/NavScroll/useSizeDetector.ts
var DEFAULT_DELAY = 150;
var useSizeDetector = ({
  root,
  isHorizontal,
  activeId,
  onChange,
  setForceRecompute,
  updateActiveId,
  hasWindow
}) => {
  const [targetSize, setTargetSize] = (0, import_react.useState)(1);
  const useViewport = root == null || hasWindow && (isHorizontal ? window.innerWidth < root.clientWidth : window.innerHeight < root.clientHeight);
  const scrollEnd = (0, import_react.useCallback)(
    debounce(() => {
      setForceRecompute(true);
    }, DEFAULT_DELAY),
    [setForceRecompute]
  );
  (0, import_react.useEffect)(() => {
    if (!hasWindow) {
      return;
    }
    let observer = null;
    const resizeWindowHandler = () => {
      setTimeout(() => {
        setTargetSize(isHorizontal ? window.innerWidth : window.innerHeight);
      }, DEFAULT_DELAY);
    };
    const resizeElementHandler = (entries) => {
      const [entry] = entries;
      if (!useViewport) {
        setTargetSize(isHorizontal ? entry.boundingClientRect.width : entry.boundingClientRect.height);
      }
      if (entry.intersectionRatio === 0) {
        if (activeId != null) {
          updateActiveId(null);
          if (onChange) {
            onChange({
              added: null,
              removed: activeId
            });
          }
        }
      }
    };
    addEventListener("scroll", scrollEnd);
    if (useViewport) {
      setTargetSize(isHorizontal ? window.innerWidth : window.innerHeight);
      addEventListener("resize", resizeWindowHandler);
    }
    if (root) {
      observer = new IntersectionObserver(resizeElementHandler);
      observer.observe(root);
    }
    return () => {
      if (observer) {
        observer.disconnect();
      }
      removeEventListener("resize", resizeWindowHandler);
      removeEventListener("scroll", scrollEnd);
    };
  }, [root, isHorizontal, activeId, onChange, useViewport, scrollEnd, hasWindow, updateActiveId]);
  return { targetSize, useViewport };
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  useSizeDetector
});
//# sourceMappingURL=useSizeDetector.cjs.map